/**
 * @Description 指令单API
 * @Author 何伯法
 * @Date 2023-08-14 10:50
 * @LastEditors 何伯法
 * @LastEditTime 2023-09-19 09:26
 */

import request from '@/utils/request'
import { merge } from 'lodash'

// 列表搜索参数
export const MANU_ORDER_QUERY = {
    custName: null, // 客人名称
    facName: null, // 生产工厂
    styleNum: null, // 工厂款号
    custNum: null, // 客人款号
    manuNum: null, // 指令号
    beginDate: null, // 开始：工厂交期
    endDate: null, // 结束：工厂交期
    status: null, // 状态：0-生产 1-完成
    createBy: null, // 创建人
    createTime: null, // 创建时间
    pageNum: 1, // 页面索引
    pageSize: 15 // 分页数量
}

/**
 * 查询指令单列表
 * @permi manu:ord:list
 * @param { MANU_ORDER_QUERY } query 查询条件
 * @returns { Object } {total,rows:[]}
 */
export function listManuOrder(query) {
    return request({
        url: '/manu/ord/list',
        method: 'get',
        params: merge({}, MANU_ORDER_QUERY, query)
    })
};

/**
 * 获取指令单
 * @permi manu:ord:view || manu:ord:edit
 * @param {Number} id 指令单ID
 * @returns {Object} {data}
 */
export function getManuOrder(id) {
    return request({
        url: '/manu/ord/' + id,
        method: 'get'
    })
};

/**
 * 添加指令单
 * @permi manu:ord:add
 * @param {Object} data 指令单数据
 * @returns {Object} {data}
 */
export function addManuOrder(data) {
    return request({
        url: '/manu/ord',
        method: 'post',
        data: data
    })
};

/**
 * 修改指令单
 * @permi manu:ord:edit
 * @param {Object} data 指令单数据
 * @returns {Object} {data}
 */
export function editManuOrder(data) {
    return request({
        url: '/manu/ord',
        method: 'put',
        data: data
    })
};

/**
 * 删除指令单
 * @permi manu:ord:delete
 * @param {Number} ids 指令单ID集合
 * @returns {Object} {data}
 */
export function deleteManuOrder(ids) {
    return request({
        url: '/manu/ord/' + (ids || []).join(','),
        method: 'delete'
    })
};

/**
 * 完成指令单
 * @permi manu:ord:complete
 * @param {Number} ids 指令单ID集合
 * @returns {Object} {data}
 */
export function completeManuOrder(ids) {
    return request({
        url: '/manu/ord/complete',
        method: 'get',
        params: { ids: (ids || []).join(','), status: '1' }
    })
};

/**
 * 下载导入模板（指令单）
 * @permi ['manu:ord:add', 'customer:order:edit'] 导入所需权限
 * @param 
 * @returns 
 */
export function downloadTemplate() {
    return request({
        url: '/manu/ord/download_template',
        method: 'get'
    })
};


/**
 * 通过鞋款查询指令单列表
 * @permi
 * @param 
 * @returns 
 */
export function getStyleNumList() {
    return request({
        url: '/manu/ord/style_num',
        method: 'get'
    })
};

