/**
 * @Description 报价API
 * @Author 何伯法
 * @Date 2024-04-20
 * @LastEditors 何伯法
 * @LastEditTime 2024-04-20
 */
import request from '@/utils/request'
import { merge } from 'lodash'


// 列表搜索参数
export const QUOTATION_QUERY = {
	company: null, // 公司
	cust: null, // 客人
	color: null, // 颜色
	beginOrderDate: null, // 下单日期：开始
	endOrderDate: null, // 下单日期：结束
	createBy: null, // 创建人
	createTime: null, // 创建时间
	pageNum: 1, // 页面索引
	pageSize: 15 // 分页数量
}

/**
 * 查询
 * @permi trade:quotation:list
 * @param {QUOTATION_QUERY} query 查询条件
 * @returns {Object}
 */
export function listQuotation(query) {
	return request({
		url: '/trade/quotation/list',
		method: 'get',
		params: merge({}, QUOTATION_QUERY, query)
	})
};

/**
 * 获取
 * @permi trade:quotation:view || trade:quotation:edit
 * @param {Number} id ID
 * @returns {Object} {data}
 */
export function getQuotation(id) {
	return request({
		url: '/trade/quotation/' + id,
		method: 'get'
	})
};


/* 表单参数 */
export const QUOTATION_FROM = {
	remark: null, // 备注
	fob: null, // 价格
	createBy: null, // 创建人
	createTime: null // 创建时间
}

/**
 * 添加
 * @permi trade:quotation:add
 * @param {QUOTATION_FROM} data 数据
 * @returns {Object} {data}
 */
export function addQuotation(data) {
	return request({
		url: '/trade/quotation',
		method: 'post',
		data: merge({}, QUOTATION_FROM, data)
	})
};