/**
 * @Description 外贸API
 * @Author 何伯法
 * @Date 2024-04-17
 * @LastEditors 何伯法
 * @LastEditTime 2024-04-17
 */
import request from '@/utils/request'
import { merge } from 'lodash'

// 列表搜索参数
export const SHOE_STYLE_QUERY = {
	styleNum: null, // 工厂款号
	version: null, // 版本号
	color: null, // 颜色
	beginOrderDate: null, // 下单日期：开始
	endOrderDate: null, // 下单日期：结束
	createBy: null, // 创建人
	createTime: null, // 创建时间
	pageNum: 1, // 页面索引
	pageSize: 15 // 分页数量
}

/**
 * 查询
 * @permi trade:style:list
 * @param {SHOE_STYLE_QUERY} query 查询条件
 * @returns {Object}
 */
export function listShoeStyle(query) {
	return request({
		url: '/trade/style/list',
		method: 'get',
		params: merge({}, SHOE_STYLE_QUERY, query)
	})
};

/**
 * 通过IDS查询
 * @permi trade:style:list
 * @param {Array} ids 查询条件
 * @returns {Array}
 */
export function queryByIds(ids) {
	return request({
		url: '/trade/style/ids',
		method: 'get',
		params: { ids: (ids || []).join(',') }
	})
};

/* 表单参数 */
export const QUOTATION_FROM = {
	remark: null, // 备注
	fob: null, // 价格
	createBy: null, // 创建人
	createTime: null // 创建时间
}

/**
 * 添加
 * @permi trade:quotation:add
 * @param {QUOTATION_FROM} data 数据
 * @returns {Object} {data}
 */

export function addOutRep(data) {
	return request({
		url: '/trade/style/inout/add',
		method: 'post',
		data: data
	})
};

/**
 * jsd
 * @permi trade:style:remove
 * @param {Number} ids ID集合
 * @returns {Object} {data}
 */
export function getSign(query) {
	return request({
		url: '/api/sns/wx/jssdk_sign',
		method: 'get',
		params: merge({}, query)
	})
};

/**
 * 获取
 * @permi trade:style:view || trade:style:edit
 * @param {Number} id ID
 * @returns {Object} {data}
 */
export function getShoeStyle(id) {
	return request({
		url: '/trade/style/' + id,
		method: 'get'
	})
};



/* 表单参数 */
export const SHOE_STYLE_FROM = {
	styleNum: null, // 鞋款
	version: null, // 版本
	color: null, // 颜色
	orderDate: null, // 下单日期
	foto: null, // 鞋图
	pice: null, // 鞋底图
	enColor: null, // 英文颜色
	size: null, // 尺码
	qty: null, // 数量
	upper: null, // 面料
	lining: null, // 内衬
	insole: null, // 内里
	outsole: null, // 大底
	outsoleNumber: null, // 大底编号
	codeSegment: null, // 码段
	gender: null, // 性别
	fob: null, // 价格
	lastNumber: null, // 楦头编号
	createBy: null, // 创建人
	createTime: null // 创建时间
}

/**
 * 添加
 * @permi trade:style:add
 * @param {SHOE_STYLE_FROM} data 数据
 * @returns {Object} {data}
 */
export function addShoeStyle(data) {
	return request({
		url: '/trade/style',
		method: 'post',
		data: merge({}, SHOE_STYLE_FROM, data)
	})
};

/**
 * 编辑
 * @permi trade:style:update
 * @param {SHOE_STYLE_FROM} data 数据
 * @returns {Object} {data}
 */
export function editShoeStyle(data) {
	return request({
		url: '/trade/style',
		method: 'post',
		data: merge({}, SHOE_STYLE_FROM, data)
	})
};

/**
 * 删除
 * @permi trade:style:remove
 * @param {Number} ids ID集合
 * @returns {Object} {data}
 */
export function deleteShoeStyle(ids) {
	return request({
		url: '/trade/style/' + (ids || []).join(','),
		method: 'delete'
	})
};

/**
 * 下载导入模板
 * @permi 
 * @param 
 * @returns 
 */
export function downloadTemplate() {
	return request({
		url: '/trade/style/download_template',
		method: 'get'
	})
};